@@ -79,6 +79,12 @@ class PropTypes:
             raise TypeError(f'expecting type `bytes`, got `{type(v)}`')
         return v
 
+    @staticmethod
+    def bool_(v):
+        if not isinstance(v, bool):
+            raise TypeError(f'expecting type `bool`, got `{type(v)}`')
+        return v
+
     @staticmethod
     def int_(v):
         if not isinstance(v, int):
@@ -109,6 +115,19 @@ class PropTypes:
             raise ValueError(f'expecting an integer value < 0, got {v}')
         return v
 
+    @staticmethod
+    def float_(v):
+        if not isinstance(v, float):
+            raise TypeError(f'expecting type `float`, got `{type(v)}`')
+        return v
+
+    @staticmethod
+    def number_(v):
+        if not isinstance(v, (float, int)):
+            raise TypeError(
+                f'expecting type `int` or `float`, got `{type(v)}`')
+        return v
+
     @staticmethod
     def array_(v, nested):
         if not isinstance(v, list):
